@@ -130,5 +130,5 @@
       )
   })
   
-  combineWidgets(list=plots, title = main, width = width, height = height)
+  combineWidgets(list=unname(plots), title = main, width = width, height = height)
 }
\ No newline at end of file
